Meta Rest API — Rucio 1.2 documentation

# Meta Rest API

Overview

Resource | Operation | Description
--- | --- | ---
Meta | POST /meta/(key) | Create new key.
| GET /meta/ | List all keys.
Values | POST /meta/(key)/ | Create new value.
| GET /meta/(key)/ | List all key values.

Details

`POST` `/meta/`(key)

  Create a new allowed key (value is NULL).

  Request JSON Object:
  | parameter (dict) – Dictionary with ‘value_type’, ‘value_regexp’ and ‘key_type’.
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json parameter list. 400 Bad Request – Unsupported Value Type. 401 Unauthorized – Invalid Auth Token. 409 Conflict – Key already exists. 500 Internal Server Error – Internal Error.

`GET` `/meta/`

  List all data identifier keys.

  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | List of all DID keys.

`POST` `/meta/`(key)`/`

  Create a new value for a key.

  Request JSON Object:
  | parameter (dict) – Dictionary with ‘value’.
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json parameter list. 400 Bad Request – Invalid Value For Key. 401 Unauthorized – Invalid Auth Token. 404 Not Found – Key Not Found. 409 Conflict – Value already exists. 500 Internal Server Error – Internal Error.

`GET` `/meta/`(key)`/`

  List all values for a key.

  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | List of all key values.